==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaDyaqLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;


/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 抵押权属性结构
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(name = "ba_dyaq_ls")
public class BaDyaqLs implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    @Nullable
    @ywh
    private String ssywh;

    @XmlAttribute
    private String dyjelx;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String dybdclx;

    @XmlAttribute
    @encrypt
    private String dyr;

    @XmlAttribute
    private String dyfs;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    @Nullable
    private String zjjzwzl;

    @XmlAttribute
    @Nullable
    private String zjjzwdyfw;

    @XmlAttribute
    private float bdbzzqse;

    @XmlAttribute
    private Date zwlxqssj;

    @XmlAttribute
    private Date zwlxjssj;

    @XmlAttribute
    @Nullable
    private String zgzqqdss;

    @XmlAttribute
    @Nullable
    private float zgzqse;

    @XmlAttribute
    @Nullable
    @ywh
    private String zxdyywh;

    @XmlAttribute
    @Nullable
    private String zxdyyy;

    @XmlAttribute
    private Date zxsj;

    @XmlAttribute
    private String bdcdjzmh;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    private String qszt;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String dyrlx;

    @XmlAttribute
    private String dyqsw;

    @XmlAttribute
    private String sfygdj;

    @XmlAttribute
    private float dymj;

    @XmlAttribute
    private String mjdw;

    @XmlAttribute
    private String bz;

    @XmlAttribute
    private String jedw;

    @XmlAttribute
    private String dbfw;

    @XmlAttribute
    private String dyqx;

    @XmlAttribute
    private String sfczjzhxz;

    @XmlAttribute
    private String zxdbr;

    /**
     * @author <a href="mailto:huming@gtmap.cn">huming</a>
     * @description 注销报文名称
     */
    private String zxbwmc;

    @sqlx
    private String sqlx;

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getZxbwmc() {
        return zxbwmc;
    }

    public void setZxbwmc(String zxbwmc) {
        this.zxbwmc = zxbwmc;
    }

    public String getDyrlx() {
        return dyrlx;
    }

    public void setDyrlx(String dyrlx) {
        this.dyrlx = dyrlx;
    }

    public String getDyqsw() {
        return dyqsw;
    }

    public void setDyqsw(String dyqsw) {
        this.dyqsw = dyqsw;
    }

    public String getSfygdj() {
        return sfygdj;
    }

    public void setSfygdj(String sfygdj) {
        this.sfygdj = sfygdj;
    }

    public float getDymj() {
        return dymj;
    }

    public void setDymj(float dymj) {
        this.dymj = dymj;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getJedw() {
        return jedw;
    }

    public void setJedw(String jedw) {
        this.jedw = jedw;
    }

    public String getDbfw() {
        return dbfw;
    }

    public void setDbfw(String dbfw) {
        this.dbfw = dbfw;
    }

    public String getDyqx() {
        return dyqx;
    }

    public void setDyqx(String dyqx) {
        this.dyqx = dyqx;
    }

    public String getSfczjzhxz() {
        return sfczjzhxz;
    }

    public void setSfczjzhxz(String sfczjzhxz) {
        this.sfczjzhxz = sfczjzhxz;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }


    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getDybdclx() {
        return dybdclx;
    }

    public String getDyr() {
        return dyr;
    }

    public String getDyfs() {
        return dyfs;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getZjjzwzl() {
        return zjjzwzl;
    }

    public String getZjjzwdyfw() {
        return zjjzwdyfw;
    }

    public float getBdbzzqse() {
        return bdbzzqse;
    }

    public String getZgzqqdss() {
        return zgzqqdss;
    }

    public float getZgzqse() {
        return zgzqse;
    }

    public String getZxdyywh() {
        return zxdyywh;
    }

    public String getZxdyyy() {
        return zxdyyy;
    }

    public Date getZxsj() {
        return zxsj;
    }

    public String getBdcdjzmh() {
        return bdcdjzmh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setDybdclx(String dybdclx) {
        this.dybdclx = dybdclx;
    }

    public void setDyr(String dyr) {
        this.dyr = dyr;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setZjjzwzl(String zjjzwzl) {
        this.zjjzwzl = zjjzwzl;
    }

    public void setZjjzwdyfw(String zjjzwdyfw) {
        this.zjjzwdyfw = zjjzwdyfw;
    }

    public void setBdbzzqse(float bdbzzqse) {
        this.bdbzzqse = bdbzzqse;
    }


    public void setZgzqqdss(String zgzqqdss) {
        this.zgzqqdss = zgzqqdss;
    }

    public void setZgzqse(float zgzqse) {
        this.zgzqse = zgzqse;
    }

    public void setZxdyywh(String zxdyywh) {
        this.zxdyywh = zxdyywh;
    }

    public void setZxdyyy(String zxdyyy) {
        this.zxdyyy = zxdyyy;
    }

    public void setZxsj(Date zxsj) {
        this.zxsj = zxsj;
    }

    public void setBdcdjzmh(String bdcdjzmh) {
        this.bdcdjzmh = bdcdjzmh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }


    public Date getZwlxqssj() {
        return zwlxqssj;
    }

    public void setZwlxqssj(Date zwlxqssj) {
        this.zwlxqssj = zwlxqssj;
    }

    public Date getZwlxjssj() {
        return zwlxjssj;
    }

    public void setZwlxjssj(Date zwlxjssj) {
        this.zwlxjssj = zwlxjssj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String scywh) {
        this.ssywh = ssywh;
    }

    public String getDyjelx() {
        return dyjelx;
    }

    public void setDyjelx(String dyjelx) {
        this.dyjelx = dyjelx;
    }


}

==> realestate-supervise-common-1.1.0-20251204.013828-71-sources.jar: cn/gtmap/realestate/supervise/entity/BaDyaqLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;


/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 抵押权属性结构
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(name = "ba_dyaq_ls")
public class BaDyaqLs implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    @Nullable
    @ywh
    private String ssywh;

    @XmlAttribute
    private String dyjelx;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String dybdclx;

    @XmlAttribute
    @encrypt
    private String dyr;

    @XmlAttribute
    private String dyfs;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    @Nullable
    private String zjjzwzl;

    @XmlAttribute
    @Nullable
    private String zjjzwdyfw;

    @XmlAttribute
    private float bdbzzqse;

    @XmlAttribute
    private Date zwlxqssj;

    @XmlAttribute
    private Date zwlxjssj;

    @XmlAttribute
    @Nullable
    private String zgzqqdss;

    @XmlAttribute
    @Nullable
    private float zgzqse;

    @XmlAttribute
    @Nullable
    @ywh
    private String zxdyywh;

    @XmlAttribute
    @Nullable
    private String zxdyyy;

    @XmlAttribute
    private Date zxsj;

    @XmlAttribute
    private String bdcdjzmh;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    private String qszt;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String dyrlx;

    @XmlAttribute
    private String dyqsw;

    @XmlAttribute
    private String sfygdj;

    @XmlAttribute
    private float dymj;

    @XmlAttribute
    private String mjdw;

    @XmlAttribute
    private String bz;

    @XmlAttribute
    private String jedw;

    @XmlAttribute
    private String dbfw;

    @XmlAttribute
    private String dyqx;

    @XmlAttribute
    private String sfczjzhxz;

    @XmlAttribute
    private String zxdbr;

    /**
     * @author <a href="mailto:huming@gtmap.cn">huming</a>
     * @description 注销报文名称
     */
    private String zxbwmc;

    @sqlx
    private String sqlx;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段开始===============

    /** 是否存在禁止或限制抵押不动产设立居住权的约定 */
    @XmlAttribute
    private String sfczxzsljzq;

    /** 原不动产单元号 */
    @XmlAttribute
    private String ybdcdyh;

    /** 用地用海分类代码 */
    @XmlAttribute
    private String ydyhfldm;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段结束===============

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getZxbwmc() {
        return zxbwmc;
    }

    public void setZxbwmc(String zxbwmc) {
        this.zxbwmc = zxbwmc;
    }

    public String getDyrlx() {
        return dyrlx;
    }

    public void setDyrlx(String dyrlx) {
        this.dyrlx = dyrlx;
    }

    public String getDyqsw() {
        return dyqsw;
    }

    public void setDyqsw(String dyqsw) {
        this.dyqsw = dyqsw;
    }

    public String getSfygdj() {
        return sfygdj;
    }

    public void setSfygdj(String sfygdj) {
        this.sfygdj = sfygdj;
    }

    public float getDymj() {
        return dymj;
    }

    public void setDymj(float dymj) {
        this.dymj = dymj;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getJedw() {
        return jedw;
    }

    public void setJedw(String jedw) {
        this.jedw = jedw;
    }

    public String getDbfw() {
        return dbfw;
    }

    public void setDbfw(String dbfw) {
        this.dbfw = dbfw;
    }

    public String getDyqx() {
        return dyqx;
    }

    public void setDyqx(String dyqx) {
        this.dyqx = dyqx;
    }

    public String getSfczjzhxz() {
        return sfczjzhxz;
    }

    public void setSfczjzhxz(String sfczjzhxz) {
        this.sfczjzhxz = sfczjzhxz;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }


    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getDybdclx() {
        return dybdclx;
    }

    public String getDyr() {
        return dyr;
    }

    public String getDyfs() {
        return dyfs;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getZjjzwzl() {
        return zjjzwzl;
    }

    public String getZjjzwdyfw() {
        return zjjzwdyfw;
    }

    public float getBdbzzqse() {
        return bdbzzqse;
    }

    public String getZgzqqdss() {
        return zgzqqdss;
    }

    public float getZgzqse() {
        return zgzqse;
    }

    public String getZxdyywh() {
        return zxdyywh;
    }

    public String getZxdyyy() {
        return zxdyyy;
    }

    public Date getZxsj() {
        return zxsj;
    }

    public String getBdcdjzmh() {
        return bdcdjzmh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setDybdclx(String dybdclx) {
        this.dybdclx = dybdclx;
    }

    public void setDyr(String dyr) {
        this.dyr = dyr;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setZjjzwzl(String zjjzwzl) {
        this.zjjzwzl = zjjzwzl;
    }

    public void setZjjzwdyfw(String zjjzwdyfw) {
        this.zjjzwdyfw = zjjzwdyfw;
    }

    public void setBdbzzqse(float bdbzzqse) {
        this.bdbzzqse = bdbzzqse;
    }


    public void setZgzqqdss(String zgzqqdss) {
        this.zgzqqdss = zgzqqdss;
    }

    public void setZgzqse(float zgzqse) {
        this.zgzqse = zgzqse;
    }

    public void setZxdyywh(String zxdyywh) {
        this.zxdyywh = zxdyywh;
    }

    public void setZxdyyy(String zxdyyy) {
        this.zxdyyy = zxdyyy;
    }

    public void setZxsj(Date zxsj) {
        this.zxsj = zxsj;
    }

    public void setBdcdjzmh(String bdcdjzmh) {
        this.bdcdjzmh = bdcdjzmh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }


    public Date getZwlxqssj() {
        return zwlxqssj;
    }

    public void setZwlxqssj(Date zwlxqssj) {
        this.zwlxqssj = zwlxqssj;
    }

    public Date getZwlxjssj() {
        return zwlxjssj;
    }

    public void setZwlxjssj(Date zwlxjssj) {
        this.zwlxjssj = zwlxjssj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String scywh) {
        this.ssywh = ssywh;
    }

    public String getDyjelx() {
        return dyjelx;
    }

    public void setDyjelx(String dyjelx) {
        this.dyjelx = dyjelx;
    }

    public String getSfczxzsljzq() {
        return sfczxzsljzq;
    }

    public void setSfczxzsljzq(String sfczxzsljzq) {
        this.sfczxzsljzq = sfczxzsljzq;
    }

    public String getYbdcdyh() {
        return ybdcdyh;
    }

    public void setYbdcdyh(String ybdcdyh) {
        this.ybdcdyh = ybdcdyh;
    }

    public String getYdyhfldm() {
        return ydyhfldm;
    }

    public void setYdyhfldm(String ydyhfldm) {
        this.ydyhfldm = ydyhfldm;
    }
}
